Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(986)

Unified Diff: ui/views/style/platform_style.h

Issue 2379993005: Label selection experiment (Closed)
Patch Set: -- Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/selection_controller.cc ('k') | ui/views/style/platform_style.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/style/platform_style.h
diff --git a/ui/views/style/platform_style.h b/ui/views/style/platform_style.h
index b4cf8deba49e45b235a1634ad8ef74d6903e5c70..5476db183fe43dd0b8f72ee9fdf6b3697d56fded 100644
--- a/ui/views/style/platform_style.h
+++ b/ui/views/style/platform_style.h
@@ -41,9 +41,9 @@ class VIEWS_EXPORT PlatformStyle {
// Whether the default button for a dialog can be the Cancel button.
static const bool kDialogDefaultButtonCanBeCancel;
// Whether dragging vertically above or below a textfield's bounds selects to
// the left or right end of the text from the cursor, respectively.
- static const bool kTextfieldDragVerticallyDragsToEnd;
+ static const bool kTextDragVerticallyDragsToEnd;
// The menu button's action to show the menu.
static const CustomButton::NotifyAction kMenuNotifyActivationAction;
« no previous file with comments | « ui/views/selection_controller.cc ('k') | ui/views/style/platform_style.cc » ('j') | no next file with comments »
@@ -41,9 +41,9 @@ class VIEWS_EXPORT PlatformStyle {
// Whether the default button for a dialog can be the Cancel button.
static const bool kDialogDefaultButtonCanBeCancel;
- // Whether dragging vertically above or below a textfield's bounds selects to
+ // Whether dragging vertically above or below a text view's bounds selects to
// the left or right end of the text from the cursor, respectively.

Powered by Google App Engine
This is Rietveld 408576698